
#line 3 "util/hostfile/hostfile_lex.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer orte_util_hostfile__create_buffer
#define yy_delete_buffer orte_util_hostfile__delete_buffer
#define yy_flex_debug orte_util_hostfile__flex_debug
#define yy_init_buffer orte_util_hostfile__init_buffer
#define yy_flush_buffer orte_util_hostfile__flush_buffer
#define yy_load_buffer_state orte_util_hostfile__load_buffer_state
#define yy_switch_to_buffer orte_util_hostfile__switch_to_buffer
#define yyin orte_util_hostfile_in
#define yyleng orte_util_hostfile_leng
#define yylex orte_util_hostfile_lex
#define yylineno orte_util_hostfile_lineno
#define yyout orte_util_hostfile_out
#define yyrestart orte_util_hostfile_restart
#define yytext orte_util_hostfile_text
#define yywrap orte_util_hostfile_wrap
#define yyalloc orte_util_hostfile_alloc
#define yyrealloc orte_util_hostfile_realloc
#define yyfree orte_util_hostfile_free

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE orte_util_hostfile_restart(orte_util_hostfile_in  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int orte_util_hostfile_leng;

extern FILE *orte_util_hostfile_in, *orte_util_hostfile_out;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up orte_util_hostfile_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up orte_util_hostfile_text again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via orte_util_hostfile_restart()), so that the user can continue scanning by
	 * just pointing orte_util_hostfile_in at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when orte_util_hostfile_text is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int orte_util_hostfile_leng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow orte_util_hostfile_wrap()'s to do buffer switches
 * instead of setting up a fresh orte_util_hostfile_in.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void orte_util_hostfile_restart (FILE *input_file  );
void orte_util_hostfile__switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE orte_util_hostfile__create_buffer (FILE *file,int size  );
void orte_util_hostfile__delete_buffer (YY_BUFFER_STATE b  );
void orte_util_hostfile__flush_buffer (YY_BUFFER_STATE b  );
void orte_util_hostfile_push_buffer_state (YY_BUFFER_STATE new_buffer  );
void orte_util_hostfile_pop_buffer_state (void );

static void orte_util_hostfile_ensure_buffer_stack (void );
static void orte_util_hostfile__load_buffer_state (void );
static void orte_util_hostfile__init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER orte_util_hostfile__flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE orte_util_hostfile__scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE orte_util_hostfile__scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE orte_util_hostfile__scan_bytes (yyconst char *bytes,int len  );

void *orte_util_hostfile_alloc (yy_size_t  );
void *orte_util_hostfile_realloc (void *,yy_size_t  );
void orte_util_hostfile_free (void *  );

#define yy_new_buffer orte_util_hostfile__create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        orte_util_hostfile_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            orte_util_hostfile__create_buffer(orte_util_hostfile_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        orte_util_hostfile_ensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            orte_util_hostfile__create_buffer(orte_util_hostfile_in,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

typedef unsigned char YY_CHAR;

FILE *orte_util_hostfile_in = (FILE *) 0, *orte_util_hostfile_out = (FILE *) 0;

typedef int yy_state_type;

extern int orte_util_hostfile_lineno;

int orte_util_hostfile_lineno = 1;

extern char *orte_util_hostfile_text;
#define yytext_ptr orte_util_hostfile_text

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up orte_util_hostfile_text.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	orte_util_hostfile_leng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 48
#define YY_END_OF_BUFFER 49
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[245] =
    {   0,
       43,   43,    5,    5,   49,   47,   10,    1,   47,   47,
       43,   47,   47,   42,   43,   11,   43,   43,   47,   43,
       43,   43,   43,   43,   43,    5,    7,    6,   10,    1,
        0,    9,    0,    2,   43,   41,    0,    4,    0,   43,
       46,   42,   43,   43,   43,    0,   43,   43,   46,    0,
       43,   43,   43,   43,   43,   43,   43,   43,    5,    6,
        6,    8,    0,   39,    0,    3,   46,   42,   43,   43,
       43,   43,    0,    0,   43,   43,   43,    0,    0,   43,
       43,   43,   12,   43,   43,   43,   43,   43,   40,   46,
       46,   42,   43,   43,   43,   43,    0,    0,   45,   43,

       43,   46,   43,   43,   43,   43,   43,   43,   43,   27,
       28,   43,   43,   46,   46,   42,   43,   43,    0,   45,
       43,   43,   43,   36,   13,   43,   43,   43,   43,   43,
       43,   14,   43,   43,   43,   43,   46,   46,   43,    0,
       45,   43,   32,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   44,   46,   45,   43,   43,   43,   43,   19,   20,
       43,   21,   43,   43,   22,   43,   43,   43,   33,   43,
       43,   43,   44,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   29,   44,   43,

       43,   23,   24,   25,   17,   26,   18,   15,   16,   43,
       43,   30,   31,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   43,   43,   43,
       43,   43,   43,   43,   43,   43,   43,   38,   37,   43,
       43,   35,   34,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        2,    2,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    4,    5,    1,    1,    1,    1,    1,
        1,    6,    7,    8,    9,   10,   11,   12,   12,   12,
       12,   12,   12,   12,   12,   12,   12,   13,    1,    1,
       14,    1,    1,   15,   16,   16,   16,   16,   17,   16,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
        1,    1,    1,   19,   20,    1,   21,   22,   23,   24,

       25,   16,   18,   18,   18,   18,   26,   27,   28,   29,
       30,   31,   18,   32,   33,   34,   35,   18,   18,   36,
       18,   18,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[37] =
    {   0,
        1,    1,    2,    3,    1,    4,    1,    5,    6,    7,
        1,    8,    9,    1,   10,    8,    8,   11,    1,    6,
        8,    8,    8,    8,    8,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11
    } ;

static yyconst flex_int16_t yy_base[264] =
    {   0,
        0,    0,   34,   35,  557,  558,   40,  558,  552,  552,
        0,   22,   38,   46,   79,  558,   36,   95,    0,   76,
      103,  533,  532,   23,  519,    0,  558,   54,   82,  558,
      547,  558,  547,  558,    0,  536,  536,  558,  544,    0,
      534,  123,    0,  143,   77,   86,  168,  182,    0,  530,
      523,   62,  508,  506,  512,  510,  516,  513,    0,   87,
      103,  558,  525,  524,  532,  558,  111,  196,  112,  216,
      115,  243,  521,  124,  257,    0,  271,  518,    0,  500,
      506,  501,  121,  122,  503,  494,  501,  494,  513,  512,
      126,  141,  510,    0,  285,  176,  509,  183,  508,  299,

      313,    0,  496,  486,  484,  489,  488,  177,  178,    0,
      482,  489,  319,  185,  503,  500,  337,  501,  497,  496,
      495,  351,  474,  123,  207,  485,  484,  152,  477,  184,
      476,  252,  468,  472,  471,  478,  486,  265,  484,  472,
      471,  467,    0,  448,  447,  449,  443,  433,  429,  429,
      428,  432,  424,  423,  404,  397,  395,  387,  398,  392,
      343,  358,  359,  353,  340,  339,  336,  335,    0,    0,
      326,    0,  318,  322,    0,  316,  326,  325,  280,  317,
      316,  318,  330,  309,  308,  297,  296,  297,  294,  292,
      286,  282,  281,  283,  282,  287,  280,    0,    0,  295,

      283,    0,    0,    0,    0,    0,    0,    0,    0,  274,
      273,    0,    0,  258,  257,  254,  253,  254,  246,  262,
      250,  240,  239,  236,  235,  228,  209,  200,  193,  184,
      177,  141,  136,  116,   95,   94,   78,    0,    0,   33,
       21,    0,    0,  558,  376,  387,  398,  406,  410,  421,
      432,  443,  449,  458,  462,  466,  473,  475,  479,  481,
      483,  485,  487
    } ;

static yyconst flex_int16_t yy_def[264] =
    {   0,
      244,    1,  245,  245,  244,  244,  244,  244,  246,  247,
      248,  244,  244,  244,  248,  244,   14,   14,  249,   14,
       14,   18,   18,   18,   18,  250,  244,  251,  244,  244,
      246,  244,  247,  244,  248,  244,  244,  244,  252,   18,
      253,   14,   15,  244,   42,  254,  248,   15,  253,  255,
       18,   18,   18,   18,   18,   18,   18,   18,  250,  251,
      251,  244,  244,  244,  252,  244,  253,   42,   68,  244,
       70,   70,  256,  257,   47,   48,   47,  255,  258,   18,
       18,   18,   18,   18,   18,   18,   18,   18,  244,  253,
      253,   18,   18,   72,   70,   95,  259,  257,  260,   47,

       47,  253,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,  253,  253,   18,   95,  117,  261,  262,
      248,   47,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,  253,  253,   72,  244,
      263,  248,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,  253,  253,  244,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,  253,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,  253,   18,

       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,   18,   18,   18,   18,   18,   18,   18,
       18,   18,   18,    0,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244
    } ;

static yyconst flex_int16_t yy_nxt[595] =
    {   0,
        6,    7,    8,    9,   10,   11,   12,   11,   11,    6,
       13,   14,   15,   16,   11,   17,   17,   18,   19,   11,
       17,   20,   21,   17,   17,   18,   18,   22,   18,   18,
       18,   23,   24,   18,   25,   18,   27,   27,   36,   28,
       28,   29,   30,   38,  243,   49,   36,   45,   39,   56,
       37,   35,   57,   35,   40,   41,  242,   42,   43,   61,
       44,   45,   45,   40,   62,   40,   45,   45,   45,   45,
       45,   40,   40,   40,   40,   40,   40,   40,   40,   40,
       40,   40,   46,   29,   30,   49,   49,   45,   69,   46,
       47,   48,  244,   81,   47,   47,   82,  244,   74,   47,

       47,   47,   47,   47,   49,   51,   40,   35,   61,  241,
       40,   40,   49,   62,   45,   40,   40,   40,   40,   40,
       90,   49,   91,   93,   49,  240,   96,   46,  239,  106,
      108,  144,   52,   53,   68,   90,   74,  115,   69,   69,
      107,  109,  145,   69,   69,   69,   69,   69,   35,  238,
       35,   35,  116,   43,   70,   43,  237,   35,   71,   71,
       72,  236,   35,   71,   71,   71,   71,   71,   72,   72,
       72,   72,   72,   72,   72,   72,   72,   72,   72,   75,
       76,  150,  151,   75,   75,   49,  244,  118,   75,   75,
       75,   75,   75,   77,  137,   98,  138,   77,   77,  128,

      130,  235,   77,   77,   77,   77,   77,   92,  234,  129,
      131,   93,   93,  153,  154,  146,   93,   93,   93,   93,
       93,   35,  233,   35,   94,   41,  147,   95,   43,  232,
       35,   96,   96,   94,  231,   94,   96,   96,   96,   96,
       96,   94,   94,   94,   94,   94,   94,   94,   94,   94,
       94,   94,   49,  230,   94,   35,  229,  228,   94,   94,
      156,  227,  226,   94,   94,   94,   94,   94,  100,  225,
      224,  157,  100,  100,  137,  223,  163,  100,  100,  100,
      100,  100,  101,  222,  221,  220,  101,  101,  194,  219,
      218,  101,  101,  101,  101,  101,  117,  217,  216,  195,

      118,  118,  215,  214,  213,  118,  118,  118,  118,  118,
      121,  212,  211,  210,  121,  121,  209,  208,  207,  121,
      121,  121,  121,  121,  122,  206,  205,  134,  122,  122,
      204,  203,  202,  122,  122,  122,  122,  122,  135,  201,
      200,  199,  198,  197,  196,  193,  192,  136,  139,  191,
      190,  189,  139,  139,  188,  187,  186,  139,  139,  139,
      139,  139,  142,  185,  184,   98,  142,  142,  137,  183,
      182,  142,  142,  142,  142,  142,   26,   26,   26,   26,
       26,   26,   26,   26,   26,   26,   26,   31,   31,   31,
       31,   31,   31,   31,   31,   31,   31,   31,   33,   33,

       33,   33,   33,   33,   33,   33,   33,   33,   33,   35,
       35,   35,  181,   35,   35,   35,   35,   50,  180,  179,
       50,   59,  178,   59,  177,   59,   59,   59,   59,   59,
       59,   59,   60,  176,   60,   60,   60,   60,   60,   60,
       60,   60,   60,   65,   65,   65,   65,   65,   65,   65,
       65,   65,   65,   65,   49,   49,   49,  175,  174,   49,
       73,  173,  172,  171,  170,   73,   73,   78,  169,   78,
      168,   78,   78,   97,   97,   99,  167,  166,  165,   76,
       99,   99,  102,   98,   98,  102,  119,  119,  120,  120,
      140,  140,  141,  141,  164,  164,   43,  162,  161,  160,

      159,  158,  155,  152,  149,  148,  143,   76,   98,   98,
       49,  116,   90,  133,  132,  127,  126,  125,  124,  123,
       98,   98,   43,  114,   89,  113,  112,  111,  110,  105,
      104,  103,   79,   98,   66,   64,   89,   88,   87,   86,
       85,   84,   83,   80,   79,   67,   66,   64,   63,   34,
       32,   58,   55,   54,   34,   32,  244,    5,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244

    } ;

static yyconst flex_int16_t yy_chk[595] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    3,    4,   12,    3,
        4,    7,    7,   13,  241,   17,   12,   17,   13,   24,
       12,   14,   24,   14,   14,   14,  240,   14,   14,   28,
       14,   14,   14,   14,   28,   14,   14,   14,   14,   14,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   15,   29,   29,   20,   45,   20,   45,   46,
       15,   15,   60,   52,   15,   15,   52,   60,   46,   15,

       15,   15,   15,   15,   18,   20,   18,   18,   61,  237,
       18,   18,   21,   61,   21,   18,   18,   18,   18,   18,
       67,   69,   67,   69,   71,  236,   71,   74,  235,   83,
       84,  124,   21,   21,   42,   91,   74,   91,   42,   42,
       83,   84,  124,   42,   42,   42,   42,   42,   44,  234,
       44,   44,   92,   92,   44,   44,  233,   44,   44,   44,
       44,  232,   44,   44,   44,   44,   44,   44,   44,   44,
       44,   44,   44,   44,   44,   44,   44,   44,   44,   47,
       47,  128,  128,   47,   47,   96,   98,   96,   47,   47,
       47,   47,   47,   48,  114,   98,  114,   48,   48,  108,

      109,  231,   48,   48,   48,   48,   48,   68,  230,  108,
      109,   68,   68,  130,  130,  125,   68,   68,   68,   68,
       68,   70,  229,   70,   70,   70,  125,   70,   70,  228,
       70,   70,   70,   70,  227,   70,   70,   70,   70,   70,
       70,   70,   70,   70,   70,   70,   70,   70,   70,   70,
       70,   70,   72,  226,   72,   72,  225,  224,   72,   72,
      132,  223,  222,   72,   72,   72,   72,   72,   75,  221,
      220,  132,   75,   75,  138,  219,  138,   75,   75,   75,
       75,   75,   77,  218,  217,  216,   77,   77,  179,  215,
      214,   77,   77,   77,   77,   77,   95,  211,  210,  179,

       95,   95,  201,  200,  197,   95,   95,   95,   95,   95,
      100,  196,  195,  194,  100,  100,  193,  192,  191,  100,
      100,  100,  100,  100,  101,  190,  189,  113,  101,  101,
      188,  187,  186,  101,  101,  101,  101,  101,  113,  185,
      184,  183,  182,  181,  180,  178,  177,  113,  117,  176,
      174,  173,  117,  117,  171,  168,  167,  117,  117,  117,
      117,  117,  122,  166,  165,  164,  122,  122,  163,  162,
      161,  122,  122,  122,  122,  122,  245,  245,  245,  245,
      245,  245,  245,  245,  245,  245,  245,  246,  246,  246,
      246,  246,  246,  246,  246,  246,  246,  246,  247,  247,

      247,  247,  247,  247,  247,  247,  247,  247,  247,  248,
      248,  248,  160,  248,  248,  248,  248,  249,  159,  158,
      249,  250,  157,  250,  156,  250,  250,  250,  250,  250,
      250,  250,  251,  155,  251,  251,  251,  251,  251,  251,
      251,  251,  251,  252,  252,  252,  252,  252,  252,  252,
      252,  252,  252,  252,  253,  253,  253,  154,  153,  253,
      254,  152,  151,  150,  149,  254,  254,  255,  148,  255,
      147,  255,  255,  256,  256,  257,  146,  145,  144,  142,
      257,  257,  258,  141,  140,  258,  259,  259,  260,  260,
      261,  261,  262,  262,  263,  263,  139,  137,  136,  135,

      134,  133,  131,  129,  127,  126,  123,  121,  120,  119,
      118,  116,  115,  112,  111,  107,  106,  105,  104,  103,
       99,   97,   93,   90,   89,   88,   87,   86,   85,   82,
       81,   80,   78,   73,   65,   64,   63,   58,   57,   56,
       55,   54,   53,   51,   50,   41,   39,   37,   36,   33,
       31,   25,   23,   22,   10,    9,    5,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244,  244,  244,  244,  244,  244,  244,
      244,  244,  244,  244

    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int orte_util_hostfile__flex_debug;
int orte_util_hostfile__flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *orte_util_hostfile_text;
#line 1 "util/hostfile/hostfile_lex.l"
#define YY_NO_INPUT 1
#line 5 "util/hostfile/hostfile_lex.l"
/*
 * Copyright (c) 2004-2005 The Trustees of Indiana University and Indiana
 *                         University Research and Technology
 *                         Corporation.  All rights reserved.
 * Copyright (c) 2004-2006 The University of Tennessee and The University
 *                         of Tennessee Research Foundation.  All rights
 *                         reserved.
 * Copyright (c) 2004-2005 High Performance Computing Center Stuttgart,
 *                         University of Stuttgart.  All rights reserved.
 * Copyright (c) 2004-2005 The Regents of the University of California.
 *                         All rights reserved.
 * Copyright (c) 2011      Cisco Systems, Inc.  All rights reserved.
 * Copyright (c) 2015      Research Organization for Information Science
 *                         and Technology (RIST). All rights reserved.
 * $COPYRIGHT$
 *
 * Additional copyrights may follow
 *
 * $HEADER$
 */
#include "orte_config.h"

#include <stdio.h>
#ifdef HAVE_UNISTD_H
#include <unistd.h>
#endif

#include "orte/util/hostfile/hostfile_lex.h"

/*
 * local functions
 */
BEGIN_C_DECLS

int orte_util_hostfile_wrap(void);

END_C_DECLS

int orte_util_hostfile_wrap(void)
{
    orte_util_hostfile_done = true;
    return 1;
}

/*
 * global variables
 */
int orte_util_hostfile_line=1;
orte_hostfile_value_t orte_util_hostfile_value = {0};
bool orte_util_hostfile_done = false;


#line 737 "util/hostfile/hostfile_lex.c"

#define INITIAL 0
#define comment 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int orte_util_hostfile_lex_destroy (void );

int orte_util_hostfile_get_debug (void );

void orte_util_hostfile_set_debug (int debug_flag  );

YY_EXTRA_TYPE orte_util_hostfile_get_extra (void );

void orte_util_hostfile_set_extra (YY_EXTRA_TYPE user_defined  );

FILE *orte_util_hostfile_get_in (void );

void orte_util_hostfile_set_in  (FILE * in_str  );

FILE *orte_util_hostfile_get_out (void );

void orte_util_hostfile_set_out  (FILE * out_str  );

int orte_util_hostfile_get_leng (void );

char *orte_util_hostfile_get_text (void );

int orte_util_hostfile_get_lineno (void );

void orte_util_hostfile_set_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int orte_util_hostfile_wrap (void );
#else
extern int orte_util_hostfile_wrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( orte_util_hostfile_text, orte_util_hostfile_leng, 1, orte_util_hostfile_out )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( orte_util_hostfile_in )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( orte_util_hostfile_in ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, orte_util_hostfile_in))==0 && ferror(orte_util_hostfile_in)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(orte_util_hostfile_in); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int orte_util_hostfile_lex (void);

#define YY_DECL int orte_util_hostfile_lex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after orte_util_hostfile_text and orte_util_hostfile_leng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
#line 62 "util/hostfile/hostfile_lex.l"


#line 921 "util/hostfile/hostfile_lex.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! orte_util_hostfile_in )
			orte_util_hostfile_in = stdin;

		if ( ! orte_util_hostfile_out )
			orte_util_hostfile_out = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			orte_util_hostfile_ensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				orte_util_hostfile__create_buffer(orte_util_hostfile_in,YY_BUF_SIZE );
		}

		orte_util_hostfile__load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of orte_util_hostfile_text. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 245 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 558 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 64 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_line++;
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 66 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_line++;
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 3:
/* rule 3 can match eol */
YY_RULE_SETUP
#line 68 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_line++;
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 71 "util/hostfile/hostfile_lex.l"
{ BEGIN(comment);
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 73 "util/hostfile/hostfile_lex.l"
; /* Eat up non '*'s */
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 74 "util/hostfile/hostfile_lex.l"
; /* Eat '*'s not followed by a '/' */
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 75 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_line++;
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 77 "util/hostfile/hostfile_lex.l"
{ BEGIN(INITIAL); /* Done with Block Comment */
                     return ORTE_HOSTFILE_NEWLINE; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 80 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_QUOTED_STRING; }
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 83 "util/hostfile/hostfile_lex.l"
;			/* whitespace */
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 85 "util/hostfile/hostfile_lex.l"
{ return ORTE_HOSTFILE_EQUAL; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 87 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_CPU; }
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 89 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_COUNT; }
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 91 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS; }
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 93 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 95 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 97 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 99 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 101 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 103 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 105 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 107 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 109 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 111 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 113 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 115 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOTS_MAX; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 118 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_RANK; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 120 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SLOT; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 123 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_USERNAME; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 125 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_USERNAME; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 127 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_USERNAME; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 130 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_BOARDS; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 133 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SOCKETS_PER_BOARD; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 136 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SOCKETS_PER_BOARD; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 139 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_SOCKETS_PER_BOARD; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 142 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_CORES_PER_SOCKET; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 145 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_CORES_PER_SOCKET; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 148 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_CORES_PER_SOCKET; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 151 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_RELATIVE; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 153 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_RELATIVE; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 155 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_RELATIVE; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 159 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.ival = atol(orte_util_hostfile_text);
                     return ORTE_HOSTFILE_INT; }
	YY_BREAK
 /* First detect hosts as standard Strings (but without ".")
    * then username@IPv4 or IPV4, then username@IPv6 or IPv6,
    * followed by username@hostname or hostname
    */

case 43:
YY_RULE_SETUP
#line 167 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_STRING; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 170 "util/hostfile/hostfile_lex.l"
{
                      orte_util_hostfile_value.sval = orte_util_hostfile_text;
                      return ORTE_HOSTFILE_IPV4; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 174 "util/hostfile/hostfile_lex.l"
{
                      orte_util_hostfile_value.sval = orte_util_hostfile_text;
                      return ORTE_HOSTFILE_IPV6; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 178 "util/hostfile/hostfile_lex.l"
{
                     orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_HOSTNAME; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 182 "util/hostfile/hostfile_lex.l"
{ orte_util_hostfile_value.sval = orte_util_hostfile_text;
                     return ORTE_HOSTFILE_ERROR; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 185 "util/hostfile/hostfile_lex.l"
ECHO;
	YY_BREAK
#line 1300 "util/hostfile/hostfile_lex.c"
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(comment):
	yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed orte_util_hostfile_in at a new source and called
			 * orte_util_hostfile_lex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = orte_util_hostfile_in;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( orte_util_hostfile_wrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * orte_util_hostfile_text, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of orte_util_hostfile_lex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					orte_util_hostfile_realloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			orte_util_hostfile_restart(orte_util_hostfile_in  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) orte_util_hostfile_realloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 245 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    	register char *yy_cp = (yy_c_buf_p);

	register YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 245 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 244);

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					orte_util_hostfile_restart(orte_util_hostfile_in );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( orte_util_hostfile_wrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve orte_util_hostfile_text */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void orte_util_hostfile_restart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        orte_util_hostfile_ensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            orte_util_hostfile__create_buffer(orte_util_hostfile_in,YY_BUF_SIZE );
	}

	orte_util_hostfile__init_buffer(YY_CURRENT_BUFFER,input_file );
	orte_util_hostfile__load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void orte_util_hostfile__switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		orte_util_hostfile_pop_buffer_state();
	 *		orte_util_hostfile_push_buffer_state(new_buffer);
     */
	orte_util_hostfile_ensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	orte_util_hostfile__load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (orte_util_hostfile_wrap()) processing, but the only time this flag
	 * is looked at is after orte_util_hostfile_wrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void orte_util_hostfile__load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	orte_util_hostfile_in = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE orte_util_hostfile__create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) orte_util_hostfile_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile__create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) orte_util_hostfile_alloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile__create_buffer()" );

	b->yy_is_our_buffer = 1;

	orte_util_hostfile__init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with orte_util_hostfile__create_buffer()
 * 
 */
    void orte_util_hostfile__delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		orte_util_hostfile_free((void *) b->yy_ch_buf  );

	orte_util_hostfile_free((void *) b  );
}

#ifndef __cplusplus
extern int isatty (int );
#endif /* __cplusplus */
    
/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a orte_util_hostfile_restart() or at EOF.
 */
    static void orte_util_hostfile__init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	orte_util_hostfile__flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then orte_util_hostfile__init_buffer was _probably_
     * called from orte_util_hostfile_restart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void orte_util_hostfile__flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		orte_util_hostfile__load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void orte_util_hostfile_push_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	orte_util_hostfile_ensure_buffer_stack();

	/* This block is copied from orte_util_hostfile__switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from orte_util_hostfile__switch_to_buffer. */
	orte_util_hostfile__load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void orte_util_hostfile_pop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	orte_util_hostfile__delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		orte_util_hostfile__load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void orte_util_hostfile_ensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)orte_util_hostfile_alloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile_ensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)orte_util_hostfile_realloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile_ensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE orte_util_hostfile__scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) orte_util_hostfile_alloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile__scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	orte_util_hostfile__switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to orte_util_hostfile_lex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       orte_util_hostfile__scan_bytes() instead.
 */
YY_BUFFER_STATE orte_util_hostfile__scan_string (yyconst char * yystr )
{
    
	return orte_util_hostfile__scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to orte_util_hostfile_lex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE orte_util_hostfile__scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) orte_util_hostfile_alloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in orte_util_hostfile__scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = orte_util_hostfile__scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in orte_util_hostfile__scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up orte_util_hostfile_text. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		orte_util_hostfile_text[orte_util_hostfile_leng] = (yy_hold_char); \
		(yy_c_buf_p) = orte_util_hostfile_text + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		orte_util_hostfile_leng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int orte_util_hostfile_get_lineno  (void)
{
        
    return orte_util_hostfile_lineno;
}

/** Get the input stream.
 * 
 */
FILE *orte_util_hostfile_get_in  (void)
{
        return orte_util_hostfile_in;
}

/** Get the output stream.
 * 
 */
FILE *orte_util_hostfile_get_out  (void)
{
        return orte_util_hostfile_out;
}

/** Get the length of the current token.
 * 
 */
int orte_util_hostfile_get_leng  (void)
{
        return orte_util_hostfile_leng;
}

/** Get the current token.
 * 
 */

char *orte_util_hostfile_get_text  (void)
{
        return orte_util_hostfile_text;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void orte_util_hostfile_set_lineno (int  line_number )
{
    
    orte_util_hostfile_lineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see orte_util_hostfile__switch_to_buffer
 */
void orte_util_hostfile_set_in (FILE *  in_str )
{
        orte_util_hostfile_in = in_str ;
}

void orte_util_hostfile_set_out (FILE *  out_str )
{
        orte_util_hostfile_out = out_str ;
}

int orte_util_hostfile_get_debug  (void)
{
        return orte_util_hostfile__flex_debug;
}

void orte_util_hostfile_set_debug (int  bdebug )
{
        orte_util_hostfile__flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from orte_util_hostfile_lex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    orte_util_hostfile_in = stdin;
    orte_util_hostfile_out = stdout;
#else
    orte_util_hostfile_in = (FILE *) 0;
    orte_util_hostfile_out = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * orte_util_hostfile_lex_init()
     */
    return 0;
}

/* orte_util_hostfile_lex_destroy is for both reentrant and non-reentrant scanners. */
int orte_util_hostfile_lex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		orte_util_hostfile__delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		orte_util_hostfile_pop_buffer_state();
	}

	/* Destroy the stack itself. */
	orte_util_hostfile_free((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * orte_util_hostfile_lex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *orte_util_hostfile_alloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *orte_util_hostfile_realloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void orte_util_hostfile_free (void * ptr )
{
	free( (char *) ptr );	/* see orte_util_hostfile_realloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 185 "util/hostfile/hostfile_lex.l"



